@@ -4,13 +4,14 @@
 #include <openbabel/mol.h>
 #include <openbabel/parsmart.h>
 #include <openbabel/obconversion.h>
-#include <openbabel/fingerprint.h>
 
 namespace OpenBabel {
     class OBMol;
     class OBSmartsPattern;
     class OBConversion;
-    class OBFingerprint;
+
+    // Debug
+    void print_global_instances();
 
     // OBConversion
     std::unique_ptr<OBMol> OBConversion_smi_to_mol(const std::string &smiles);
@@ -22,8 +23,9 @@ namespace OpenBabel {
     double OBMol_get_mol_wt(const std::unique_ptr<OBMol> & pMol);
 
     // OBFingerprint
-    // std::unique_ptr<OBFingerprint> OBFingerprint_find(const std::string &fp_name);
-    std::unique_ptr<std::vector<unsigned int>> OBFingerprint_get_fingerprint(const std::string &fp_name, const std::unique_ptr<OBMol> & pMol, u_int32_t nbits);
+    typedef std::vector<unsigned int> FPData;
+    std::unique_ptr<FPData> OBFingerprint_get_fingerprint(const std::string &fp_thread_name, const std::unique_ptr<OBMol> & pMol, u_int32_t nbits);
+    std::unique_ptr<FPData> OBFingerprint_get_fingerprint_in_batch(const std::string &fp_thread_name, const rust::Vec<rust::String> & smiles_vec, u_int32_t nbits);
 
     // OBSmartsPattern
     std::unique_ptr<OBSmartsPattern> OBSmartsPattern_new(const std::string &smarts);
